aboutsummaryrefslogtreecommitdiffstats
path: root/storage/storer.go
diff options
context:
space:
mode:
Diffstat (limited to 'storage/storer.go')
-rw-r--r--storage/storer.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/storage/storer.go b/storage/storer.go
index d217209..50bfd55 100644
--- a/storage/storer.go
+++ b/storage/storer.go
@@ -1,12 +1,12 @@
package storage
import (
- "srcd.works/go-git.v4/config"
- "srcd.works/go-git.v4/plumbing/storer"
+ "gopkg.in/src-d/go-git.v4/config"
+ "gopkg.in/src-d/go-git.v4/plumbing/storer"
)
// Storer is a generic storage of objects, references and any information
// related to a particular repository. The package srcd.works/go-git.v4/storage
// contains two implementation a filesystem base implementation (such as `.git`)
// and a memory implementations being ephemeral
type Storer interface {
@@ -1,12 +1,12 @@
)
// Storer is a generic storage of objects, references and any information
-// related to a particular repository. The package srcd.works/go-git.v4/storage
+// related to a particular repository. The package gopkg.in/src-d/go-git.v4/storage
// contains two implementation a filesystem base implementation (such as `.git`)
// and a memory implementations being ephemeral